.. index::
   single: pdistreport; --help

.. _pdistreport_script:

``pdistreport``
---------------

.. program-output:: pdistreport --help
   :prompt:
   :shell:

.. seealso:: :ref:`showing_distributions`
